aboutsummaryrefslogtreecommitdiffstats
path: root/ui/app/account-detail.js
diff options
context:
space:
mode:
Diffstat (limited to 'ui/app/account-detail.js')
-rw-r--r--ui/app/account-detail.js14
1 files changed, 13 insertions, 1 deletions
diff --git a/ui/app/account-detail.js b/ui/app/account-detail.js
index 6d50dbd71..b1b0495eb 100644
--- a/ui/app/account-detail.js
+++ b/ui/app/account-detail.js
@@ -28,6 +28,7 @@ function mapStateToProps (state) {
network: state.metamask.network,
unconfTxs: valuesFor(state.metamask.unconfTxs),
unconfMsgs: valuesFor(state.metamask.unconfMsgs),
+ isEthWarningConfirmed: state.metamask.isEthConfirmed,
}
}
@@ -171,6 +172,16 @@ AccountDetailScreen.prototype.render = function () {
}),
h('button', {
+ onClick: () => props.dispatch(actions.buyEth(selected)),
+ style: {
+ marginBottom: '20px',
+ marginRight: '8px',
+ position: 'absolute',
+ left: '219px',
+ },
+ }, 'BUY'),
+
+ h('button', {
onClick: () => props.dispatch(actions.showSendPage()),
style: {
marginBottom: '20px',
@@ -181,7 +192,7 @@ AccountDetailScreen.prototype.render = function () {
]),
]),
// subview (tx history, pk export confirm)
h(ReactCSSTransitionGroup, {
className: 'css-transition-group',
transitionName: 'main',
@@ -239,3 +250,4 @@ AccountDetailScreen.prototype.transactionList = function () {
AccountDetailScreen.prototype.requestAccountExport = function () {
this.props.dispatch(actions.requestExportAccount())
}
+
@@ -181,7 +192,7 @@ AccountDetailScreen.prototype.render = function () {
]),
]),
- // subview (tx history, pk export confirm)
+ // subview (tx history, pk export confirm, buy eth warning)
h(ReactCSSTransitionGroup, {
className: 'css-transition-group',